==> mongodb-6.0.27.gh.tar.gz: mongo-r6.0.27/src/mongo/db/s/balancer/cluster_statistics_mock.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/s/balancer/cluster_statistics.h"

namespace mongo {

/**
 * Mock implementation for the cluster statistics gathering utility.
 * Empty/missing stats values trigger a failure when getStats()/getCollStats() are invoked.
 */
class ClusterStatisticsMock final : public ClusterStatistics {
public:
    ClusterStatisticsMock() {}

    ~ClusterStatisticsMock() {}

    void setStats(std::vector<ShardStatistics>&& clusterStats,
                  std::map<NamespaceString, std::vector<ShardStatistics>>&& collStats) {
        _clusterStats.swap(clusterStats);
        _collStats.swap(collStats);
    }

    StatusWith<std::vector<ShardStatistics>> getStats(OperationContext* opCtx) override {

        if (_clusterStats.empty()) {
            return Status(ErrorCodes::DataCorruptionDetected,
                          "Failure on getStats() raised by mock");
        }
        return _clusterStats;
    }

    StatusWith<std::vector<ShardStatistics>> getCollStats(OperationContext* opCtx,
                                                          NamespaceString const& ns) override {
        auto& stats = _collStats[ns];
        if (stats.empty()) {
            return Status(ErrorCodes::DataCorruptionDetected,
                          "Failure on getCollStats() raised by mock");
        }
        return stats;
    }

private:
    std::vector<ShardStatistics> _clusterStats;

    std::map<NamespaceString, std::vector<ShardStatistics>> _collStats;

    bool _forceErrorOnGetStats{false};

    bool _forceErrorOnGetCollStats{false};
};

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/s/balancer/cluster_statistics_mock.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/s/balancer/cluster_statistics.h"

namespace mongo {

/**
 * Mock implementation for the cluster statistics gathering utility.
 * Empty/missing stats values trigger a failure when getStats()/getCollStats() are invoked.
 */
class ClusterStatisticsMock final : public ClusterStatistics {
public:
    ClusterStatisticsMock() {}

    ~ClusterStatisticsMock() override {}

    void setStats(std::vector<ShardStatistics>&& clusterStats) {
        _clusterStats.swap(clusterStats);
    }

    StatusWith<std::vector<ShardStatistics>> getStats(OperationContext* opCtx) override {

        if (_clusterStats.empty()) {
            return Status(ErrorCodes::DataCorruptionDetected,
                          "Failure on getStats() raised by mock");
        }
        return _clusterStats;
    }

private:
    std::vector<ShardStatistics> _clusterStats;

    bool _forceErrorOnGetStats{false};

    bool _forceErrorOnGetCollStats{false};
};

}  // namespace mongo
